@@ -14,7 +14,7 @@ from django.utils.translation import ugettext_lazy as _l
 
 from .config import settings
 from .exceptions import MissingContextVariableError
-from .helpers import DeletedRelatedObject, SecureRelatedObject, get_from_context
+from .helpers import DeletedRelatedObject, SecureRelatedObject, get_from_context, strip_html
 
 
 class BaseModel(SmartModel):
@@ -55,9 +55,12 @@ class AdminNotificationTemplate(BaseTemplate):
     Attributes:
         slug: Template slug, with which this template can be referred to.
         is_active: Flag that switches on/off creating notifications from this template.
+        send_push: Flag that switches on/off sending push notifications from this template.
+            Currently, it has no effect on its own, but you can use it in your custom push notification solution.
     """
     slug = models.SlugField(max_length=200, unique=True, verbose_name=_l('slug'))
     is_active = models.BooleanField(default=True, verbose_name=_l('is active'))
+    send_push = models.BooleanField(default=False, verbose_name=_l('send push notification'))
 
     class Meta:
         verbose_name = _l('admin notification template')
@@ -113,7 +116,12 @@ class NotificationTemplate(BaseTemplate):
                 if value is None or isinstance(value, DeletedRelatedObject):
                     raise MissingContextVariableError(field, var)
 
-        return Template('{}{}'.format(settings.TEMPLATE_PREFIX, template_string)).render(Context(context))
+        output = Template('{}{}'.format(settings.TEMPLATE_PREFIX, template_string)).render(Context(context))
+
+        if settings.STRIP_HTML:
+            output = strip_html(output)
+
+        return output
 
 
 class NotificationQuerySet(SmartQuerySet):
